{ inputs, lib, config, pkgs, ... }: {
  imports = [
    ../common
    ./hardware-configuration.nix
    ../services/postgres.nix
    ../desktop
    ../desktop/plasma.nix
  ];

  nixpkgs = { config = { allowUnfree = true; }; };

  nix = let flakeInputs = lib.filterAttrs (_: lib.isType "flake") inputs;
  in {
    settings = {
      flake-registry = "";
      nix-path = config.nix.nixPath;
    };
    channel.enable = false;

    registry = lib.mapAttrs (_: flake: { inherit flake; }) flakeInputs;
    nixPath = lib.mapAttrsToList (n: _: "${n}=flake:${n}") flakeInputs;
  };

  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "enoko";

  time.timeZone = "Europe/Berlin";

  i18n.defaultLocale = "en_US.UTF-8";
  i18n.extraLocaleSettings = {
    LC_ADDRESS = "de_DE.UTF-8";
    LC_IDENTIFICATION = "de_DE.UTF-8";
    LC_MEASUREMENT = "de_DE.UTF-8";
    LC_MONETARY = "de_DE.UTF-8";
    LC_NAME = "de_DE.UTF-8";
    LC_NUMERIC = "de_DE.UTF-8";
    LC_PAPER = "de_DE.UTF-8";
    LC_TELEPHONE = "de_DE.UTF-8";
    LC_TIME = "de_DE.UTF-8";
  };

  services.xserver.xkb = {
    layout = "us";
    variant = "";
  };
  services.fwupd.enable = true;
  powerManagement.enable = true;

  users.users = {
    lu = {
      shell = pkgs.fish;
      isNormalUser = true;
      extraGroups = [ "wheel" "storage" ];
    };
  };

  # network stuff
  networking.networkmanager = { enable = true; };

  # fish shell
  programs.fish = {
    enable = true;
    vendor = {
      completions.enable = true;
      config.enable = true;
      functions.enable = true;
    };
  };

  # enable ppd specifically for the framework
  services.power-profiles-daemon.enable = true;

  boot.kernelParams = lib.optionals
    (lib.versionOlder config.boot.kernelPackages.kernel.version "6.8")
    [ "rtc_cmos.use_acpi_alarm=1" ];

  # https://nixos.wiki/wiki/FAQ/When_do_I_update_stateVersion
  system.stateVersion = "24.05";
}
